@@ -1,6 +1,7 @@
-(* $Id: charmap.mli,v 1.6 2003/07/31 12:20:58 yori Exp $ *)
+(* $Id: charmap.mli,v 1.7 2006/08/13 17:09:17 yori Exp $ *)
 (* Copyright 2002 Yamagata Yoriyuki *)
 
+module type Interface = sig
 type enc_to_ucs
 
 val make_enc_to_ucs : int -> (string * int) list -> enc_to_ucs
@@ -20,3 +21,6 @@ type t = {
 type data = Alias of string | CMap of t
 
 val of_name : string -> t
+end
+
+module Configure(Config : ConfigInt.Type) : Interface
