@@ -1,6 +1,7 @@
-(* $Id: unimap.mli,v 1.2 2003/03/24 20:59:32 yori Exp $ *)
+(* $Id: unimap.mli,v 1.3 2006/08/13 17:09:17 yori Exp $ *)
 (* Copyright 2002 Yamagata Yoriyuki *)
 
+module type Type = sig
 type mapping
 val read_map : mapping -> int -> int
 
@@ -21,3 +22,6 @@ val enc_to_ucs : t -> int -> int
 val ucs_to_enc : t -> int -> int
 
 val of_name : string -> t
+end
+
+module Make (Config : ConfigInt.Type) : Type
