@@ -1,4 +1,4 @@
-(* $Id: caseMap.mli,v 1.6 2004/06/05 16:42:07 yori Exp $ *)
+(* $Id: caseMap.mli,v 1.7 2006/08/06 19:48:55 yori Exp $ *)
 (* Copyright 2002, 2004 Yamagata Yoriyuki *)
 
 (** Case mappings as defined in Unicode Technical Report #21 *)
@@ -23,5 +23,4 @@ module type Type =
     val compare_caseless : text -> text -> int
   end
 
-module Make : functor (Text : UnicodeString.Type) ->
- (Type with type text = Text.t)
+module Make (Config : ConfigInt.Type) (Text : UnicodeString.Type) :  (Type with type text = Text.t)
