@@ -1,7 +1,7 @@
-(* $Id: absCe.mli,v 1.15 2003/12/19 17:24:34 yori Exp $ *)
+(* $Id: absCe.mli,v 1.16 2006/08/13 17:26:41 yori Exp $ *)
 (* Copyright 2003 Yamagata Yoriyuki *)
 
-open Unidata
+open Toolslib
 open UCol
 
 type elt =
@@ -47,7 +47,7 @@ val create_ace_info :
     ceset ->
       ace_info
 
-val cetbl_of : ace_info -> col_info
+val cetbl_of : ace_info -> Unidata.col_info
 
 type aceset_info = 
     {lowercase_first_tbl : ceset;
